.. pytroll-watchers documentation master file, created by
   sphinx-quickstart on Tue Apr  9 18:57:44 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pytroll-watchers's documentation!
============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cli
   published
   backends
   other_api
   selector

Pytroll-watcher is a library and command-line tool to detect changes on a local or remote file system.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
